# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class DiscreteTimeseriesExprTimeseries(str, enum.Enum):
    """
    ℹ️ This enum is non-exhaustive.
    """

    GLUCOSE = "glucose"
    HEARTRATE = "heartrate"
    HRV = "hrv"
    IGE = "ige"
    IGG = "igg"
    CHOLESTEROL = "cholesterol"
    WEIGHT = "weight"
    FAT = "fat"
    BLOOD_OXYGEN = "blood_oxygen"
    ELECTROCARDIOGRAM_VOLTAGE = "electrocardiogram_voltage"
    RESPIRATORY_RATE = "respiratory_rate"
    STRESS_LEVEL = "stress_level"
    _UNKNOWN = "__DISCRETETIMESERIESEXPRTIMESERIES_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "DiscreteTimeseriesExprTimeseries":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        glucose: typing.Callable[[], T_Result],
        heartrate: typing.Callable[[], T_Result],
        hrv: typing.Callable[[], T_Result],
        ige: typing.Callable[[], T_Result],
        igg: typing.Callable[[], T_Result],
        cholesterol: typing.Callable[[], T_Result],
        weight: typing.Callable[[], T_Result],
        fat: typing.Callable[[], T_Result],
        blood_oxygen: typing.Callable[[], T_Result],
        electrocardiogram_voltage: typing.Callable[[], T_Result],
        respiratory_rate: typing.Callable[[], T_Result],
        stress_level: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is DiscreteTimeseriesExprTimeseries.GLUCOSE:
            return glucose()
        if self is DiscreteTimeseriesExprTimeseries.HEARTRATE:
            return heartrate()
        if self is DiscreteTimeseriesExprTimeseries.HRV:
            return hrv()
        if self is DiscreteTimeseriesExprTimeseries.IGE:
            return ige()
        if self is DiscreteTimeseriesExprTimeseries.IGG:
            return igg()
        if self is DiscreteTimeseriesExprTimeseries.CHOLESTEROL:
            return cholesterol()
        if self is DiscreteTimeseriesExprTimeseries.WEIGHT:
            return weight()
        if self is DiscreteTimeseriesExprTimeseries.FAT:
            return fat()
        if self is DiscreteTimeseriesExprTimeseries.BLOOD_OXYGEN:
            return blood_oxygen()
        if self is DiscreteTimeseriesExprTimeseries.ELECTROCARDIOGRAM_VOLTAGE:
            return electrocardiogram_voltage()
        if self is DiscreteTimeseriesExprTimeseries.RESPIRATORY_RATE:
            return respiratory_rate()
        if self is DiscreteTimeseriesExprTimeseries.STRESS_LEVEL:
            return stress_level()
        return _unknown_member(self._value_)
