# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .provider_mfa_request_method import ProviderMfaRequestMethod


class ProviderMfaRequest(UniversalBaseModel):
    method: ProviderMfaRequestMethod = pydantic.Field()
    """
    The MFA method requested by the password provider to complete authentication. ℹ️ This enum is non-exhaustive.
    """

    hint: str = pydantic.Field()
    """
    The MFA hint provided by the password provider, e.g., the redacted phone number.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
