# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .historical_pull_completed import HistoricalPullCompleted


class ClientFacingMindfulnessMinutesHistoricalPullCompleted(UniversalBaseModel):
    event_type: typing.Literal["historical.data.mindfulness_minutes.created"] = (
        "historical.data.mindfulness_minutes.created"
    )
    user_id: str
    client_user_id: str
    team_id: str
    data: HistoricalPullCompleted

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
